# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ResultNetInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'listening': 'bool',
        'listeners': 'list[str]',
        'n_peers': 'str',
        'peers': 'list[NetInfoPeer]'
    }

    attribute_map = {
        'listening': 'listening',
        'listeners': 'listeners',
        'n_peers': 'nPeers',
        'peers': 'peers'
    }

    def __init__(self, listening=None, listeners=None, n_peers=None, peers=None):  # noqa: E501
        """ResultNetInfo - a model defined in Swagger"""  # noqa: E501
        self._listening = None
        self._listeners = None
        self._n_peers = None
        self._peers = None
        self.discriminator = None
        if listening is not None:
            self.listening = listening
        if listeners is not None:
            self.listeners = listeners
        if n_peers is not None:
            self.n_peers = n_peers
        if peers is not None:
            self.peers = peers

    @property
    def listening(self):
        """Gets the listening of this ResultNetInfo.  # noqa: E501


        :return: The listening of this ResultNetInfo.  # noqa: E501
        :rtype: bool
        """
        return self._listening

    @listening.setter
    def listening(self, listening):
        """Sets the listening of this ResultNetInfo.


        :param listening: The listening of this ResultNetInfo.  # noqa: E501
        :type: bool
        """

        self._listening = listening

    @property
    def listeners(self):
        """Gets the listeners of this ResultNetInfo.  # noqa: E501


        :return: The listeners of this ResultNetInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._listeners

    @listeners.setter
    def listeners(self, listeners):
        """Sets the listeners of this ResultNetInfo.


        :param listeners: The listeners of this ResultNetInfo.  # noqa: E501
        :type: list[str]
        """

        self._listeners = listeners

    @property
    def n_peers(self):
        """Gets the n_peers of this ResultNetInfo.  # noqa: E501


        :return: The n_peers of this ResultNetInfo.  # noqa: E501
        :rtype: str
        """
        return self._n_peers

    @n_peers.setter
    def n_peers(self, n_peers):
        """Sets the n_peers of this ResultNetInfo.


        :param n_peers: The n_peers of this ResultNetInfo.  # noqa: E501
        :type: str
        """

        self._n_peers = n_peers

    @property
    def peers(self):
        """Gets the peers of this ResultNetInfo.  # noqa: E501


        :return: The peers of this ResultNetInfo.  # noqa: E501
        :rtype: list[NetInfoPeer]
        """
        return self._peers

    @peers.setter
    def peers(self, peers):
        """Sets the peers of this ResultNetInfo.


        :param peers: The peers of this ResultNetInfo.  # noqa: E501
        :type: list[NetInfoPeer]
        """

        self._peers = peers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResultNetInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResultNetInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from enum import Enum
from typing import NamedTuple

# Assuming ContractInterface is defined elsewhere in your Python code
# from contract_interface import ContractInterface

class NativeContractKind(Enum):
    Gas = 0
    Block = 1
    Stake = 2
    Swap = 3
    Account = 4
    Consensus = 5
    Governance = 6
    Storage = 7
    Validator = 8
    Interop = 9
    Exchange = 10
    Privacy = 11
    Relay = 12
    Ranking = 13
    Market = 14
    Friends = 15
    Mail = 16
    Sale = 17
    Unknown = 18

class IContract(NamedTuple):
    Name: str
    #ABI: ContractInterface

# Example Usage
# contract = IContract(Name="MyContract", ABI=contract_interface)



# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.models.balance_result import BalanceResult  # noqa: E501
from swagger_client.rest import ApiException


class TestBalanceResult(unittest.TestCase):
    """BalanceResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testBalanceResult(self):
        """Test BalanceResult"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.balance_result.BalanceResult()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TokenResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'symbol': 'str',
        'name': 'str',
        'decimals': 'int',
        'current_supply': 'str',
        'max_supply': 'str',
        'burned_supply': 'str',
        'address': 'str',
        'owner': 'str',
        'flags': 'str',
        'script': 'str',
        'series': 'list[TokenSeriesResult]',
        'external': 'list[TokenExternalResult]',
        'price': 'list[TokenPriceResult]'
    }

    attribute_map = {
        'symbol': 'symbol',
        'name': 'name',
        'decimals': 'decimals',
        'current_supply': 'currentSupply',
        'max_supply': 'maxSupply',
        'burned_supply': 'burnedSupply',
        'address': 'address',
        'owner': 'owner',
        'flags': 'flags',
        'script': 'script',
        'series': 'series',
        'external': 'external',
        'price': 'price'
    }

    def __init__(self, symbol=None, name=None, decimals=None, current_supply=None, max_supply=None, burned_supply=None, address=None, owner=None, flags=None, script=None, series=None, external=None, price=None):  # noqa: E501
        """TokenResult - a model defined in Swagger"""  # noqa: E501
        self._symbol = None
        self._name = None
        self._decimals = None
        self._current_supply = None
        self._max_supply = None
        self._burned_supply = None
        self._address = None
        self._owner = None
        self._flags = None
        self._script = None
        self._series = None
        self._external = None
        self._price = None
        self.discriminator = None
        if symbol is not None:
            self.symbol = symbol
        if name is not None:
            self.name = name
        if decimals is not None:
            self.decimals = decimals
        if current_supply is not None:
            self.current_supply = current_supply
        if max_supply is not None:
            self.max_supply = max_supply
        if burned_supply is not None:
            self.burned_supply = burned_supply
        if address is not None:
            self.address = address
        if owner is not None:
            self.owner = owner
        if flags is not None:
            self.flags = flags
        if script is not None:
            self.script = script
        if series is not None:
            self.series = series
        if external is not None:
            self.external = external
        if price is not None:
            self.price = price

    @property
    def symbol(self):
        """Gets the symbol of this TokenResult.  # noqa: E501


        :return: The symbol of this TokenResult.  # noqa: E501
        :rtype: str
        """
        return self._symbol

    @symbol.setter
    def symbol(self, symbol):
        """Sets the symbol of this TokenResult.


        :param symbol: The symbol of this TokenResult.  # noqa: E501
        :type: str
        """

        self._symbol = symbol

    @property
    def name(self):
        """Gets the name of this TokenResult.  # noqa: E501


        :return: The name of this TokenResult.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TokenResult.


        :param name: The name of this TokenResult.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def decimals(self):
        """Gets the decimals of this TokenResult.  # noqa: E501


        :return: The decimals of this TokenResult.  # noqa: E501
        :rtype: int
        """
        return self._decimals

    @decimals.setter
    def decimals(self, decimals):
        """Sets the decimals of this TokenResult.


        :param decimals: The decimals of this TokenResult.  # noqa: E501
        :type: int
        """

        self._decimals = decimals

    @property
    def current_supply(self):
        """Gets the current_supply of this TokenResult.  # noqa: E501


        :return: The current_supply of this TokenResult.  # noqa: E501
        :rtype: str
        """
        return self._current_supply

    @current_supply.setter
    def current_supply(self, current_supply):
        """Sets the current_supply of this TokenResult.


        :param current_supply: The current_supply of this TokenResult.  # noqa: E501
        :type: str
        """

        self._current_supply = current_supply

    @property
    def max_supply(self):
        """Gets the max_supply of this TokenResult.  # noqa: E501


        :return: The max_supply of this TokenResult.  # noqa: E501
        :rtype: str
        """
        return self._max_supply

    @max_supply.setter
    def max_supply(self, max_supply):
        """Sets the max_supply of this TokenResult.


        :param max_supply: The max_supply of this TokenResult.  # noqa: E501
        :type: str
        """

        self._max_supply = max_supply

    @property
    def burned_supply(self):
        """Gets the burned_supply of this TokenResult.  # noqa: E501


        :return: The burned_supply of this TokenResult.  # noqa: E501
        :rtype: str
        """
        return self._burned_supply

    @burned_supply.setter
    def burned_supply(self, burned_supply):
        """Sets the burned_supply of this TokenResult.


        :param burned_supply: The burned_supply of this TokenResult.  # noqa: E501
        :type: str
        """

        self._burned_supply = burned_supply

    @property
    def address(self):
        """Gets the address of this TokenResult.  # noqa: E501


        :return: The address of this TokenResult.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this TokenResult.


        :param address: The address of this TokenResult.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def owner(self):
        """Gets the owner of this TokenResult.  # noqa: E501


        :return: The owner of this TokenResult.  # noqa: E501
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this TokenResult.


        :param owner: The owner of this TokenResult.  # noqa: E501
        :type: str
        """

        self._owner = owner

    @property
    def flags(self):
        """Gets the flags of this TokenResult.  # noqa: E501


        :return: The flags of this TokenResult.  # noqa: E501
        :rtype: str
        """
        return self._flags

    @flags.setter
    def flags(self, flags):
        """Sets the flags of this TokenResult.


        :param flags: The flags of this TokenResult.  # noqa: E501
        :type: str
        """

        self._flags = flags

    @property
    def script(self):
        """Gets the script of this TokenResult.  # noqa: E501


        :return: The script of this TokenResult.  # noqa: E501
        :rtype: str
        """
        return self._script

    @script.setter
    def script(self, script):
        """Sets the script of this TokenResult.


        :param script: The script of this TokenResult.  # noqa: E501
        :type: str
        """

        self._script = script

    @property
    def series(self):
        """Gets the series of this TokenResult.  # noqa: E501


        :return: The series of this TokenResult.  # noqa: E501
        :rtype: list[TokenSeriesResult]
        """
        return self._series

    @series.setter
    def series(self, series):
        """Sets the series of this TokenResult.


        :param series: The series of this TokenResult.  # noqa: E501
        :type: list[TokenSeriesResult]
        """

        self._series = series

    @property
    def external(self):
        """Gets the external of this TokenResult.  # noqa: E501


        :return: The external of this TokenResult.  # noqa: E501
        :rtype: list[TokenExternalResult]
        """
        return self._external

    @external.setter
    def external(self, external):
        """Sets the external of this TokenResult.


        :param external: The external of this TokenResult.  # noqa: E501
        :type: list[TokenExternalResult]
        """

        self._external = external

    @property
    def price(self):
        """Gets the price of this TokenResult.  # noqa: E501


        :return: The price of this TokenResult.  # noqa: E501
        :rtype: list[TokenPriceResult]
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this TokenResult.


        :param price: The price of this TokenResult.  # noqa: E501
        :type: list[TokenPriceResult]
        """

        self._price = price

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TokenResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TokenResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# Assuming PBinaryReader and PBinaryWriter are already defined
# from your previous code or another source

from enum import IntEnum


class SignatureKind(IntEnum):
    None_ = 0
    Ed25519 = 1
    ECDSA = 2


# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ResultStatusSyncInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'latest_block_hash': 'str',
        'latest_app_hash': 'str',
        'latest_block_height': 'str',
        'latest_block_time': 'str',
        'catching_up': 'bool'
    }

    attribute_map = {
        'latest_block_hash': 'latestBlockHash',
        'latest_app_hash': 'latestAppHash',
        'latest_block_height': 'latestBlockHeight',
        'latest_block_time': 'latestBlockTime',
        'catching_up': 'catchingUp'
    }

    def __init__(self, latest_block_hash=None, latest_app_hash=None, latest_block_height=None, latest_block_time=None, catching_up=None):  # noqa: E501
        """ResultStatusSyncInfo - a model defined in Swagger"""  # noqa: E501
        self._latest_block_hash = None
        self._latest_app_hash = None
        self._latest_block_height = None
        self._latest_block_time = None
        self._catching_up = None
        self.discriminator = None
        if latest_block_hash is not None:
            self.latest_block_hash = latest_block_hash
        if latest_app_hash is not None:
            self.latest_app_hash = latest_app_hash
        if latest_block_height is not None:
            self.latest_block_height = latest_block_height
        if latest_block_time is not None:
            self.latest_block_time = latest_block_time
        if catching_up is not None:
            self.catching_up = catching_up

    @property
    def latest_block_hash(self):
        """Gets the latest_block_hash of this ResultStatusSyncInfo.  # noqa: E501


        :return: The latest_block_hash of this ResultStatusSyncInfo.  # noqa: E501
        :rtype: str
        """
        return self._latest_block_hash

    @latest_block_hash.setter
    def latest_block_hash(self, latest_block_hash):
        """Sets the latest_block_hash of this ResultStatusSyncInfo.


        :param latest_block_hash: The latest_block_hash of this ResultStatusSyncInfo.  # noqa: E501
        :type: str
        """

        self._latest_block_hash = latest_block_hash

    @property
    def latest_app_hash(self):
        """Gets the latest_app_hash of this ResultStatusSyncInfo.  # noqa: E501


        :return: The latest_app_hash of this ResultStatusSyncInfo.  # noqa: E501
        :rtype: str
        """
        return self._latest_app_hash

    @latest_app_hash.setter
    def latest_app_hash(self, latest_app_hash):
        """Sets the latest_app_hash of this ResultStatusSyncInfo.


        :param latest_app_hash: The latest_app_hash of this ResultStatusSyncInfo.  # noqa: E501
        :type: str
        """

        self._latest_app_hash = latest_app_hash

    @property
    def latest_block_height(self):
        """Gets the latest_block_height of this ResultStatusSyncInfo.  # noqa: E501


        :return: The latest_block_height of this ResultStatusSyncInfo.  # noqa: E501
        :rtype: str
        """
        return self._latest_block_height

    @latest_block_height.setter
    def latest_block_height(self, latest_block_height):
        """Sets the latest_block_height of this ResultStatusSyncInfo.


        :param latest_block_height: The latest_block_height of this ResultStatusSyncInfo.  # noqa: E501
        :type: str
        """

        self._latest_block_height = latest_block_height

    @property
    def latest_block_time(self):
        """Gets the latest_block_time of this ResultStatusSyncInfo.  # noqa: E501


        :return: The latest_block_time of this ResultStatusSyncInfo.  # noqa: E501
        :rtype: str
        """
        return self._latest_block_time

    @latest_block_time.setter
    def latest_block_time(self, latest_block_time):
        """Sets the latest_block_time of this ResultStatusSyncInfo.


        :param latest_block_time: The latest_block_time of this ResultStatusSyncInfo.  # noqa: E501
        :type: str
        """

        self._latest_block_time = latest_block_time

    @property
    def catching_up(self):
        """Gets the catching_up of this ResultStatusSyncInfo.  # noqa: E501


        :return: The catching_up of this ResultStatusSyncInfo.  # noqa: E501
        :rtype: bool
        """
        return self._catching_up

    @catching_up.setter
    def catching_up(self, catching_up):
        """Sets the catching_up of this ResultStatusSyncInfo.


        :param catching_up: The catching_up of this ResultStatusSyncInfo.  # noqa: E501
        :type: bool
        """

        self._catching_up = catching_up

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResultStatusSyncInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResultStatusSyncInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from .AccountTrigger import AccountTrigger
from .AddressKind import AddressKind
from .OrganizationTrigger import OrganizationTrigger
from .TokenTrigger import TokenTrigger
from .TriggerResult import TriggerResult


from abc import ABC, abstractmethod

# Assuming PBinaryReader and PBinaryWriter are defined elsewhere in your Python code
# from p_binary_reader import PBinaryReader
# from p_binary_writer import PBinaryWriter

class ISerializable(ABC):
    @abstractmethod
    def serialize_data(self, writer: 'PBinaryWriter'):
        """
        Serialize the object data using the provided binary writer.
        """
        pass

    @abstractmethod
    def unserialize_data(self, reader: 'PBinaryReader'):
        """
        Unserialize the object data using the provided binary reader.
        """
        pass


# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PaginatedResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'page': 'int',
        'page_size': 'int',
        'total': 'int',
        'total_pages': 'int',
        'result': 'object'
    }

    attribute_map = {
        'page': 'page',
        'page_size': 'pageSize',
        'total': 'total',
        'total_pages': 'totalPages',
        'result': 'result'
    }

    def __init__(self, page=None, page_size=None, total=None, total_pages=None, result=None):  # noqa: E501
        """PaginatedResult - a model defined in Swagger"""  # noqa: E501
        self._page = None
        self._page_size = None
        self._total = None
        self._total_pages = None
        self._result = None
        self.discriminator = None
        if page is not None:
            self.page = page
        if page_size is not None:
            self.page_size = page_size
        if total is not None:
            self.total = total
        if total_pages is not None:
            self.total_pages = total_pages
        if result is not None:
            self.result = result

    @property
    def page(self):
        """Gets the page of this PaginatedResult.  # noqa: E501


        :return: The page of this PaginatedResult.  # noqa: E501
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """Sets the page of this PaginatedResult.


        :param page: The page of this PaginatedResult.  # noqa: E501
        :type: int
        """

        self._page = page

    @property
    def page_size(self):
        """Gets the page_size of this PaginatedResult.  # noqa: E501


        :return: The page_size of this PaginatedResult.  # noqa: E501
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this PaginatedResult.


        :param page_size: The page_size of this PaginatedResult.  # noqa: E501
        :type: int
        """

        self._page_size = page_size

    @property
    def total(self):
        """Gets the total of this PaginatedResult.  # noqa: E501


        :return: The total of this PaginatedResult.  # noqa: E501
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this PaginatedResult.


        :param total: The total of this PaginatedResult.  # noqa: E501
        :type: int
        """

        self._total = total

    @property
    def total_pages(self):
        """Gets the total_pages of this PaginatedResult.  # noqa: E501


        :return: The total_pages of this PaginatedResult.  # noqa: E501
        :rtype: int
        """
        return self._total_pages

    @total_pages.setter
    def total_pages(self, total_pages):
        """Sets the total_pages of this PaginatedResult.


        :param total_pages: The total_pages of this PaginatedResult.  # noqa: E501
        :type: int
        """

        self._total_pages = total_pages

    @property
    def result(self):
        """Gets the result of this PaginatedResult.  # noqa: E501


        :return: The result of this PaginatedResult.  # noqa: E501
        :rtype: object
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this PaginatedResult.


        :param result: The result of this PaginatedResult.  # noqa: E501
        :type: object
        """

        self._result = result

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PaginatedResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaginatedResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8
import sys
import os
import unittest

#sys.path.append('../../../../')

from Types import Address
from Types import PhantasmaKeys


class TestPhantasmaKeys(unittest.TestCase):

    def testPhantasmaKeys(self):
        keys = PhantasmaKeys.from_wif("KxMn2TgXukYaNXx7tEdjh7qB2YaMgeuKy47j4rvKigHhBuZWeP3r")
        assert keys.to_wif() == "KxMn2TgXukYaNXx7tEdjh7qB2YaMgeuKy47j4rvKigHhBuZWeP3r"
        assert keys.Address.Text == "P2K9zmyFDNGN6n6hHiTUAz6jqn29s5G1SWLiXwCVQcpHcQb"

        keys = PhantasmaKeys.from_wif("L2sTuSzangXQCFxXFXJqfPAKJsstKvQdkGqP9J2VFkFRbEjd1Ez6")
        assert keys.to_wif() == "L2sTuSzangXQCFxXFXJqfPAKJsstKvQdkGqP9J2VFkFRbEjd1Ez6"
        assert keys.Address.Text == "P2K65RZhfxZhQcXKGgSPZL6c6hkygXipNxdeuW5FU531Bqc"
        pass


if __name__ == '__main__':
    unittest.main()



from datetime import datetime
import binascii
from ecpy.curves import Curve, Point
from ecpy.keys import ECPublicKey, ECPrivateKey
from ecpy.eddsa import EDDSA
import hashlib

from ..VM.ScriptBuilder import ScriptBuilder


class Transaction():

    '''
    The Transaction object implements all the basic methods needed to build a Phantasma Transaction string
    and sign it with HEX PK in order to broadcast to the Phantasma Blockchain.

    Args:
        nexusName (str): mainnet (production) or testnet (testing).
        chainName (str): chain name (main).
        script (str): script to execute.
        expiration (int): expiration timestamp.
        payload (str): payload message.

    Attributes:
        nexusName (str): mainnet (production) or testnet (testing).
        chainName (str): chain name (main).
        script (str): script to execute.
        expiration (int): expiration timestamp.
        payload (str): payload message.
        signatures (list): list of signatures, at least one is needed to broadcast tx.
    '''

    nexusName: str = None
    chainName: str = None
    script: str = None
    expiration: int = None
    payload: str = None
    hash: str = None

    signatures = []

    def __init__(
            self,
            nexusName: str,
            chainName: str,
            script: str,
            expiration: int,
            payload: str = 'PHANPY-1.0') -> None:

        if expiration is None:
            now = datetime.now()
            expiration = int(datetime.timestamp(now)) + 1000

        self.nexusName = nexusName
        self.chainName = chainName
        self.script = script
        self.expiration = expiration
        self.payload = payload
        self.signatures = []

    def sign(self, pk: int) -> None:
        '''Sign the transaction with HEX PK of the Sender's Address.

        Args:
            pk (int): HEX private key. Example: 0x411d7dabb39b455aadc49897e2fa13234585116d4f5eee198105f33f8f62d0b8

        Returns:
            None (The generated signature is added to the signatures list)
        '''
        signature = self.getSign(self.toString(False), pk)
        self.signatures.insert(0, signature)

    def toString(self, withSignature: bool) -> str:
        '''By using a ScriptBuilder object this method generates the needed string to broadcast the tx to
        the Phanstasma Blockchain.

        Args:
            withSignature (bool): flags that indicates if need to attach signatures or not to the end result.

        Returns:
            toString (str): Transaction object as string.
        '''

        num = self.expiration
        a = (num & 0xff000000) >> 24
        b = (num & 0x00ff0000) >> 16
        c = (num & 0x0000ff00) >> 8
        d = num & 0x000000ff

        expirationBytes = [d, c, b, a]

        sb = ScriptBuilder()
        sb.emitVarString(self.nexusName)
        sb.emitVarString(self.chainName)
        sb.emitVarInt(int(len(self.script) / 2))
        sb.appendHexEncoded(self.script)
        sb.emitBytes(expirationBytes)
        sb.emitVarString(self.payload)

        if (withSignature):
            sb.emitVarInt(len(self.signatures))
            for s in self.signatures:
                sb.appendByte(1)
                sig = s.decode("utf-8").upper()
                sb.emitVarInt(int(len(sig) / 2))
                sb.appendHexEncoded(sig)

        return sb.data

    def getSign(self, msgHex: str, pk: int) -> bytes:
        '''Method that given a message to sign & HEX private key returns the signature needed.

        Args:
           msgHex (str): Message to sign as Hex String.
           pk (int): HEX private key. Example: 0x411d7dabb39b455aadc49897e2fa13234585116d4f5eee198105f33f8f62d0b8

        Returns:
            getSign (bytes): Signature as bytes.
        '''
        hexBytes = binascii.unhexlify(msgHex)
        hexPk = int(pk)

        cv = Curve.get_curve('Ed25519')
        pv_key = ECPrivateKey(hexPk, cv)
        signer = EDDSA(hashlib.sha512)

        sig = signer.sign(hexBytes, pv_key)
        sig = binascii.hexlify(sig)

        return(sig)



from enum import IntEnum


class Opcode(IntEnum):
    NOP = 0
    # Register
    MOVE = 1
    COPY = 2
    PUSH = 3
    POP = 4
    SWAP = 5
    # Flow
    CALL = 6
    EXTCALL = 7
    JMP = 8
    JMPIF = 9
    JMPNOT = 10
    RET = 11
    THROW = 12
    # Data
    LOAD = 13
    CAST = 14
    CAT = 15
    RANGE = 16
    LEFT = 17
    RIGHT = 18
    SIZE = 19
    COUNT = 20
    # Logical
    NOT = 21
    AND = 22
    OR = 23
    XOR = 24
    EQUAL = 25
    LT = 26
    GT = 27
    LTE = 28
    GTE = 29
    # Numeric
    INC = 30
    DEC = 31
    SIGN = 32
    NEGATE = 33
    ABS = 34
    ADD = 35
    SUB = 36
    MUL = 37
    DIV = 38
    MOD = 39
    SHL = 40
    SHR = 41
    MIN = 42
    MAX = 43
    POW = 44
    # Context
    CTX = 45
    SWITCH = 46
    # Array
    PUT = 47
    GET = 48
    CLEAR = 49
    UNPACK = 50
    PACK = 51
    # Debugger
    DEBUG = 52
    # ADD
    SUBSTR = 53



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from swagger_client.api.account_api import AccountApi
from swagger_client.api.auction_api import AuctionApi
from swagger_client.api.block_api import BlockApi
from swagger_client.api.chain_api import ChainApi
from swagger_client.api.connection_api import ConnectionApi
from swagger_client.api.contract_api import ContractApi
from swagger_client.api.leaderboard_api import LeaderboardApi
from swagger_client.api.nexus_api import NexusApi
from swagger_client.api.organization_api import OrganizationApi
from swagger_client.api.platform_api import PlatformApi
from swagger_client.api.rpc_api import RpcApi
from swagger_client.api.sale_api import SaleApi
from swagger_client.api.token_api import TokenApi
from swagger_client.api.transaction_api import TransactionApi
from swagger_client.api.validator_api import ValidatorApi



import binascii

class Base16:
    @staticmethod
    def encode(string: str) -> str:
        if not string:
            return ""
        return binascii.hexlify(string.encode()).decode()

    @staticmethod
    def encode_uint8_array(array: bytearray) -> str:
        if not array:
            return ""
        return binascii.hexlify(array).decode().upper()

    @staticmethod
    def decode(hex_string: str) -> str:
        if not hex_string or len(hex_string) % 2 != 0:
            return ""
        return binascii.unhexlify(hex_string).decode()

    @staticmethod
    def decode_uint8_array(hex_string: str) -> bytearray:
        if not hex_string or len(hex_string) % 2 != 0:
            return bytearray()
        return bytearray(binascii.unhexlify(hex_string))



# coding: utf-8

# flake8: noqa
"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from swagger_client.models.abi_event_result import ABIEventResult
from swagger_client.models.abi_method_result import ABIMethodResult
from swagger_client.models.abi_parameter_result import ABIParameterResult
from swagger_client.models.account_result import AccountResult
from swagger_client.models.address import Address
from swagger_client.models.address_kind import AddressKind
from swagger_client.models.archive_result import ArchiveResult
from swagger_client.models.auction_result import AuctionResult
from swagger_client.models.balance_result import BalanceResult
from swagger_client.models.block_result import BlockResult
from swagger_client.models.chain_result import ChainResult
from swagger_client.models.contract_result import ContractResult
from swagger_client.models.crowdsale_result import CrowdsaleResult
from swagger_client.models.event_result import EventResult
from swagger_client.models.governance_result import GovernanceResult
from swagger_client.models.interop_result import InteropResult
from swagger_client.models.leaderboard_result import LeaderboardResult
from swagger_client.models.leaderboard_row_result import LeaderboardRowResult
from swagger_client.models.net_info_peer import NetInfoPeer
from swagger_client.models.net_info_peer_connection_status import NetInfoPeerConnectionStatus
from swagger_client.models.net_info_peer_connection_status_channel import NetInfoPeerConnectionStatusChannel
from swagger_client.models.net_info_peer_connection_status_monitor import NetInfoPeerConnectionStatusMonitor
from swagger_client.models.nexus_result import NexusResult
from swagger_client.models.node_info import NodeInfo
from swagger_client.models.node_info_other import NodeInfoOther
from swagger_client.models.node_info_protocol_version import NodeInfoProtocolVersion
from swagger_client.models.oracle_result import OracleResult
from swagger_client.models.organization_result import OrganizationResult
from swagger_client.models.paginated_result import PaginatedResult
from swagger_client.models.platform_result import PlatformResult
from swagger_client.models.pub_key import PubKey
from swagger_client.models.response_query import ResponseQuery
from swagger_client.models.result_abci_query import ResultAbciQuery
from swagger_client.models.result_health import ResultHealth
from swagger_client.models.result_net_info import ResultNetInfo
from swagger_client.models.result_status import ResultStatus
from swagger_client.models.result_status_sync_info import ResultStatusSyncInfo
from swagger_client.models.result_status_validator_info import ResultStatusValidatorInfo
from swagger_client.models.rpc_request import RpcRequest
from swagger_client.models.rpc_response import RpcResponse
from swagger_client.models.script_result import ScriptResult
from swagger_client.models.signature_result import SignatureResult
from swagger_client.models.stake_result import StakeResult
from swagger_client.models.storage_result import StorageResult
from swagger_client.models.token_data_result import TokenDataResult
from swagger_client.models.token_external_result import TokenExternalResult
from swagger_client.models.token_price_result import TokenPriceResult
from swagger_client.models.token_property_result import TokenPropertyResult
from swagger_client.models.token_result import TokenResult
from swagger_client.models.token_series_result import TokenSeriesResult
from swagger_client.models.transaction_result import TransactionResult
from swagger_client.models.validator_result import ValidatorResult
from swagger_client.models.validator_settings import ValidatorSettings



# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ResultStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'node_info': 'NodeInfo',
        'sync_info': 'ResultStatusSyncInfo',
        'validator_info': 'ResultStatusValidatorInfo'
    }

    attribute_map = {
        'node_info': 'nodeInfo',
        'sync_info': 'syncInfo',
        'validator_info': 'validatorInfo'
    }

    def __init__(self, node_info=None, sync_info=None, validator_info=None):  # noqa: E501
        """ResultStatus - a model defined in Swagger"""  # noqa: E501
        self._node_info = None
        self._sync_info = None
        self._validator_info = None
        self.discriminator = None
        if node_info is not None:
            self.node_info = node_info
        if sync_info is not None:
            self.sync_info = sync_info
        if validator_info is not None:
            self.validator_info = validator_info

    @property
    def node_info(self):
        """Gets the node_info of this ResultStatus.  # noqa: E501


        :return: The node_info of this ResultStatus.  # noqa: E501
        :rtype: NodeInfo
        """
        return self._node_info

    @node_info.setter
    def node_info(self, node_info):
        """Sets the node_info of this ResultStatus.


        :param node_info: The node_info of this ResultStatus.  # noqa: E501
        :type: NodeInfo
        """

        self._node_info = node_info

    @property
    def sync_info(self):
        """Gets the sync_info of this ResultStatus.  # noqa: E501


        :return: The sync_info of this ResultStatus.  # noqa: E501
        :rtype: ResultStatusSyncInfo
        """
        return self._sync_info

    @sync_info.setter
    def sync_info(self, sync_info):
        """Sets the sync_info of this ResultStatus.


        :param sync_info: The sync_info of this ResultStatus.  # noqa: E501
        :type: ResultStatusSyncInfo
        """

        self._sync_info = sync_info

    @property
    def validator_info(self):
        """Gets the validator_info of this ResultStatus.  # noqa: E501


        :return: The validator_info of this ResultStatus.  # noqa: E501
        :rtype: ResultStatusValidatorInfo
        """
        return self._validator_info

    @validator_info.setter
    def validator_info(self, validator_info):
        """Sets the validator_info of this ResultStatus.


        :param validator_info: The validator_info of this ResultStatus.  # noqa: E501
        :type: ResultStatusValidatorInfo
        """

        self._validator_info = validator_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResultStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResultStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from .IContract import IContract
from .IKeyPair import IKeyPair
from .ISerializable import ISerializable
from .IStack import IStack
from .SignatureKind import SignatureKind
from .Signature import Signature
from .ISignature import ISignature


import binascii

def hex_to_byte_array(hex_string):
    return bytearray.fromhex(hex_string)

def hex_to_buffer(hex_string):
    return bytes.fromhex(hex_string)

def buffer_to_hex(buffer):
    return binascii.hexlify(buffer).decode('utf-8')

def reverse_hex(hex_string):
    return hex_string[::-1]

def decode_base16(hex_string):
    return bytearray.fromhex(hex_string).decode()

def encode_base16(string):
    return binascii.hexlify(string.encode()).decode('utf-8').upper()

def uint8_array_to_string(array):
    return ''.join(chr(b) for b in array)

def string_to_uint8_array(string):
    return bytearray(string, 'utf-8')

def hex_string_to_uint8_array(hex_string):
    return bytearray.fromhex(hex_string)

def hex_string_to_bytes(hex_string):
    return bytearray.fromhex(hex_string)

def get_difficulty(transaction_hash):
    bytes = hex_string_to_bytes(transaction_hash)
    bytes.reverse()
    result = 0

    for byte in bytes:
        for j in range(8):
            if byte & (1 << j):
                result = 1 + (len(bytes) - 1 - result) * 8 + j
                return 256 - result

    return 256 - result


def number_to_byte_array(num, size=None):
    if size is None:
        size = (num.bit_length() + 7) // 8
    return num.to_bytes(size, byteorder='little')

def big_int_to_byte_array(bigint):
    hex_string = bigint.to_bytes((bigint.bit_length() + 7) // 8, 'big').hex()
    return bytearray.fromhex(hex_string)

def hex2ascii(hex_string):
    return bytearray.fromhex(hex_string).decode()

def int2buffer(i):
    return i.to_bytes((i.bit_length() + 7) // 8, 'big')


import requests
import json

class PhantasmaAPI:
	base_url = None 

	def __init__(self, base_url="https://phantasma.io"):
		self.base_url = base_url
		self.session = requests.Session()
		self.session.headers.update({"Content-Type": "application/json"})

	def _request(self, method, endpoint, params=None, json=None):
		url = f"{self.base_url}{endpoint}"
		response = self.session.request(method, url, params=params, json=json)

		if response.status_code == 200:
			return response.json()
		else:
			response.raise_for_status()


	# Account methods
	def getAccount(self, account):
		endpoint = "/api/v1/GetAccount"
		params = {"account": account}
		return self._request("GET", endpoint, params=params)

	def getAccounts(self, account_text):
		endpoint = "/api/v1/GetAccounts"
		params = {"accountText": account_text}
		return self._request("GET", endpoint, params=params)


# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AccountResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'address': 'str',
        'name': 'str',
        'stakes': 'StakeResult',
        'stake': 'str',
        'unclaimed': 'str',
        'relay': 'str',
        'validator': 'str',
        'storage': 'StorageResult',
        'balances': 'list[BalanceResult]',
        'txs': 'list[str]'
    }

    attribute_map = {
        'address': 'address',
        'name': 'name',
        'stakes': 'stakes',
        'stake': 'stake',
        'unclaimed': 'unclaimed',
        'relay': 'relay',
        'validator': 'validator',
        'storage': 'storage',
        'balances': 'balances',
        'txs': 'txs'
    }

    def __init__(self, address=None, name=None, stakes=None, stake=None, unclaimed=None, relay=None, validator=None, storage=None, balances=None, txs=None):  # noqa: E501
        """AccountResult - a model defined in Swagger"""  # noqa: E501
        self._address = None
        self._name = None
        self._stakes = None
        self._stake = None
        self._unclaimed = None
        self._relay = None
        self._validator = None
        self._storage = None
        self._balances = None
        self._txs = None
        self.discriminator = None
        if address is not None:
            self.address = address
        if name is not None:
            self.name = name
        if stakes is not None:
            self.stakes = stakes
        if stake is not None:
            self.stake = stake
        if unclaimed is not None:
            self.unclaimed = unclaimed
        if relay is not None:
            self.relay = relay
        if validator is not None:
            self.validator = validator
        if storage is not None:
            self.storage = storage
        if balances is not None:
            self.balances = balances
        if txs is not None:
            self.txs = txs

    @property
    def address(self):
        """Gets the address of this AccountResult.  # noqa: E501


        :return: The address of this AccountResult.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this AccountResult.


        :param address: The address of this AccountResult.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def name(self):
        """Gets the name of this AccountResult.  # noqa: E501


        :return: The name of this AccountResult.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AccountResult.


        :param name: The name of this AccountResult.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def stakes(self):
        """Gets the stakes of this AccountResult.  # noqa: E501


        :return: The stakes of this AccountResult.  # noqa: E501
        :rtype: StakeResult
        """
        return self._stakes

    @stakes.setter
    def stakes(self, stakes):
        """Sets the stakes of this AccountResult.


        :param stakes: The stakes of this AccountResult.  # noqa: E501
        :type: StakeResult
        """

        self._stakes = stakes

    @property
    def stake(self):
        """Gets the stake of this AccountResult.  # noqa: E501


        :return: The stake of this AccountResult.  # noqa: E501
        :rtype: str
        """
        return self._stake

    @stake.setter
    def stake(self, stake):
        """Sets the stake of this AccountResult.


        :param stake: The stake of this AccountResult.  # noqa: E501
        :type: str
        """

        self._stake = stake

    @property
    def unclaimed(self):
        """Gets the unclaimed of this AccountResult.  # noqa: E501


        :return: The unclaimed of this AccountResult.  # noqa: E501
        :rtype: str
        """
        return self._unclaimed

    @unclaimed.setter
    def unclaimed(self, unclaimed):
        """Sets the unclaimed of this AccountResult.


        :param unclaimed: The unclaimed of this AccountResult.  # noqa: E501
        :type: str
        """

        self._unclaimed = unclaimed

    @property
    def relay(self):
        """Gets the relay of this AccountResult.  # noqa: E501


        :return: The relay of this AccountResult.  # noqa: E501
        :rtype: str
        """
        return self._relay

    @relay.setter
    def relay(self, relay):
        """Sets the relay of this AccountResult.


        :param relay: The relay of this AccountResult.  # noqa: E501
        :type: str
        """

        self._relay = relay

    @property
    def validator(self):
        """Gets the validator of this AccountResult.  # noqa: E501


        :return: The validator of this AccountResult.  # noqa: E501
        :rtype: str
        """
        return self._validator

    @validator.setter
    def validator(self, validator):
        """Sets the validator of this AccountResult.


        :param validator: The validator of this AccountResult.  # noqa: E501
        :type: str
        """

        self._validator = validator

    @property
    def storage(self):
        """Gets the storage of this AccountResult.  # noqa: E501


        :return: The storage of this AccountResult.  # noqa: E501
        :rtype: StorageResult
        """
        return self._storage

    @storage.setter
    def storage(self, storage):
        """Sets the storage of this AccountResult.


        :param storage: The storage of this AccountResult.  # noqa: E501
        :type: StorageResult
        """

        self._storage = storage

    @property
    def balances(self):
        """Gets the balances of this AccountResult.  # noqa: E501


        :return: The balances of this AccountResult.  # noqa: E501
        :rtype: list[BalanceResult]
        """
        return self._balances

    @balances.setter
    def balances(self, balances):
        """Sets the balances of this AccountResult.


        :param balances: The balances of this AccountResult.  # noqa: E501
        :type: list[BalanceResult]
        """

        self._balances = balances

    @property
    def txs(self):
        """Gets the txs of this AccountResult.  # noqa: E501


        :return: The txs of this AccountResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._txs

    @txs.setter
    def txs(self, txs):
        """Sets the txs of this AccountResult.


        :param txs: The txs of this AccountResult.  # noqa: E501
        :type: list[str]
        """

        self._txs = txs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AccountResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from Types.Extensions import PBinaryWriter
from cryptography.hazmat.primitives import serialization
from cryptography.hazmat.primitives.asymmetric import ed25519
from cryptography.exceptions import InvalidSignature
from typing import List

class Ed25519Signature:
    def __init__(self, bytes=None):
        self.bytes = bytes
        self.kind = "Ed25519"  # assuming SignatureKind is an enum or similar in Python

    def verify(self, message: bytes, address) -> bool:
        return self.verify_multiple(message, [address])

    def verify_multiple(self, message: bytes, addresses: List) -> bool:
        for address in addresses:
            if not address.is_user:
                continue
            public_key_bytes = address.to_byte_array()[2:]
            public_key = ed25519.Ed25519PublicKey.from_public_bytes(public_key_bytes)
            try:
                public_key.verify(self.bytes, message)
                return True
            except InvalidSignature:
                continue
        return False

    def serialize_data(self, writer) -> None:
        writer.write_byte_array(self.bytes)

    def unserialize_data(self, reader) -> None:
        self.bytes = reader.read_byte_array()

    def to_byte_array(self) -> bytes:
        # Assuming PBinaryWriter is implemented in Python
        writer = PBinaryWriter()
        self.serialize_data(writer)
        return writer.to_bytes()

    @staticmethod
    def generate(keypair, message: bytes):
        private_key = ed25519.Ed25519PrivateKey.from_private_bytes(keypair.private_key)
        signature = private_key.sign(message)
        return Ed25519Signature(signature)



# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BalanceResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'chain': 'str',
        'amount': 'str',
        'symbol': 'str',
        'decimals': 'int',
        'ids': 'list[str]'
    }

    attribute_map = {
        'chain': 'chain',
        'amount': 'amount',
        'symbol': 'symbol',
        'decimals': 'decimals',
        'ids': 'ids'
    }

    def __init__(self, chain=None, amount=None, symbol=None, decimals=None, ids=None):  # noqa: E501
        """BalanceResult - a model defined in Swagger"""  # noqa: E501
        self._chain = None
        self._amount = None
        self._symbol = None
        self._decimals = None
        self._ids = None
        self.discriminator = None
        if chain is not None:
            self.chain = chain
        if amount is not None:
            self.amount = amount
        if symbol is not None:
            self.symbol = symbol
        if decimals is not None:
            self.decimals = decimals
        if ids is not None:
            self.ids = ids

    @property
    def chain(self):
        """Gets the chain of this BalanceResult.  # noqa: E501


        :return: The chain of this BalanceResult.  # noqa: E501
        :rtype: str
        """
        return self._chain

    @chain.setter
    def chain(self, chain):
        """Sets the chain of this BalanceResult.


        :param chain: The chain of this BalanceResult.  # noqa: E501
        :type: str
        """

        self._chain = chain

    @property
    def amount(self):
        """Gets the amount of this BalanceResult.  # noqa: E501


        :return: The amount of this BalanceResult.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this BalanceResult.


        :param amount: The amount of this BalanceResult.  # noqa: E501
        :type: str
        """

        self._amount = amount

    @property
    def symbol(self):
        """Gets the symbol of this BalanceResult.  # noqa: E501


        :return: The symbol of this BalanceResult.  # noqa: E501
        :rtype: str
        """
        return self._symbol

    @symbol.setter
    def symbol(self, symbol):
        """Sets the symbol of this BalanceResult.


        :param symbol: The symbol of this BalanceResult.  # noqa: E501
        :type: str
        """

        self._symbol = symbol

    @property
    def decimals(self):
        """Gets the decimals of this BalanceResult.  # noqa: E501


        :return: The decimals of this BalanceResult.  # noqa: E501
        :rtype: int
        """
        return self._decimals

    @decimals.setter
    def decimals(self, decimals):
        """Sets the decimals of this BalanceResult.


        :param decimals: The decimals of this BalanceResult.  # noqa: E501
        :type: int
        """

        self._decimals = decimals

    @property
    def ids(self):
        """Gets the ids of this BalanceResult.  # noqa: E501


        :return: The ids of this BalanceResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._ids

    @ids.setter
    def ids(self, ids):
        """Sets the ids of this BalanceResult.


        :param ids: The ids of this BalanceResult.  # noqa: E501
        :type: list[str]
        """

        self._ids = ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BalanceResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BalanceResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



class Stack:
    def __init__(self, capacity=float('inf')):
        self.storage = []
        self.capacity = capacity

    def push(self, item):
        if self.size() == self.capacity:
            raise Exception("Stack has reached max capacity, you cannot add more items")
        self.storage.append(item)

    def pop(self):
        return self.storage.pop() if self.storage else None

    def peek(self):
        return self.storage[-1] if self.storage else None

    def size(self):
        return len(self.storage)

    def is_empty(self):
        return self.size() == 0

    def to_array(self):
        return self.storage.copy()

    def clear(self):
        self.storage = []

    def __str__(self):
        return str(self.storage)

    def is_full(self):
        return self.capacity == self.size()


# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BlockResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'hash': 'str',
        'previous_hash': 'str',
        'timestamp': 'int',
        'height': 'int',
        'chain_address': 'str',
        'protocol': 'int',
        'txs': 'list[TransactionResult]',
        'validator_address': 'str',
        'reward': 'str',
        'events': 'list[EventResult]',
        'oracles': 'list[OracleResult]'
    }

    attribute_map = {
        'hash': 'hash',
        'previous_hash': 'previousHash',
        'timestamp': 'timestamp',
        'height': 'height',
        'chain_address': 'chainAddress',
        'protocol': 'protocol',
        'txs': 'txs',
        'validator_address': 'validatorAddress',
        'reward': 'reward',
        'events': 'events',
        'oracles': 'oracles'
    }

    def __init__(self, hash=None, previous_hash=None, timestamp=None, height=None, chain_address=None, protocol=None, txs=None, validator_address=None, reward=None, events=None, oracles=None):  # noqa: E501
        """BlockResult - a model defined in Swagger"""  # noqa: E501
        self._hash = None
        self._previous_hash = None
        self._timestamp = None
        self._height = None
        self._chain_address = None
        self._protocol = None
        self._txs = None
        self._validator_address = None
        self._reward = None
        self._events = None
        self._oracles = None
        self.discriminator = None
        if hash is not None:
            self.hash = hash
        if previous_hash is not None:
            self.previous_hash = previous_hash
        if timestamp is not None:
            self.timestamp = timestamp
        if height is not None:
            self.height = height
        if chain_address is not None:
            self.chain_address = chain_address
        if protocol is not None:
            self.protocol = protocol
        if txs is not None:
            self.txs = txs
        if validator_address is not None:
            self.validator_address = validator_address
        if reward is not None:
            self.reward = reward
        if events is not None:
            self.events = events
        if oracles is not None:
            self.oracles = oracles

    @property
    def hash(self):
        """Gets the hash of this BlockResult.  # noqa: E501


        :return: The hash of this BlockResult.  # noqa: E501
        :rtype: str
        """
        return self._hash

    @hash.setter
    def hash(self, hash):
        """Sets the hash of this BlockResult.


        :param hash: The hash of this BlockResult.  # noqa: E501
        :type: str
        """

        self._hash = hash

    @property
    def previous_hash(self):
        """Gets the previous_hash of this BlockResult.  # noqa: E501


        :return: The previous_hash of this BlockResult.  # noqa: E501
        :rtype: str
        """
        return self._previous_hash

    @previous_hash.setter
    def previous_hash(self, previous_hash):
        """Sets the previous_hash of this BlockResult.


        :param previous_hash: The previous_hash of this BlockResult.  # noqa: E501
        :type: str
        """

        self._previous_hash = previous_hash

    @property
    def timestamp(self):
        """Gets the timestamp of this BlockResult.  # noqa: E501


        :return: The timestamp of this BlockResult.  # noqa: E501
        :rtype: int
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this BlockResult.


        :param timestamp: The timestamp of this BlockResult.  # noqa: E501
        :type: int
        """

        self._timestamp = timestamp

    @property
    def height(self):
        """Gets the height of this BlockResult.  # noqa: E501


        :return: The height of this BlockResult.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this BlockResult.


        :param height: The height of this BlockResult.  # noqa: E501
        :type: int
        """

        self._height = height

    @property
    def chain_address(self):
        """Gets the chain_address of this BlockResult.  # noqa: E501


        :return: The chain_address of this BlockResult.  # noqa: E501
        :rtype: str
        """
        return self._chain_address

    @chain_address.setter
    def chain_address(self, chain_address):
        """Sets the chain_address of this BlockResult.


        :param chain_address: The chain_address of this BlockResult.  # noqa: E501
        :type: str
        """

        self._chain_address = chain_address

    @property
    def protocol(self):
        """Gets the protocol of this BlockResult.  # noqa: E501


        :return: The protocol of this BlockResult.  # noqa: E501
        :rtype: int
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this BlockResult.


        :param protocol: The protocol of this BlockResult.  # noqa: E501
        :type: int
        """

        self._protocol = protocol

    @property
    def txs(self):
        """Gets the txs of this BlockResult.  # noqa: E501


        :return: The txs of this BlockResult.  # noqa: E501
        :rtype: list[TransactionResult]
        """
        return self._txs

    @txs.setter
    def txs(self, txs):
        """Sets the txs of this BlockResult.


        :param txs: The txs of this BlockResult.  # noqa: E501
        :type: list[TransactionResult]
        """

        self._txs = txs

    @property
    def validator_address(self):
        """Gets the validator_address of this BlockResult.  # noqa: E501


        :return: The validator_address of this BlockResult.  # noqa: E501
        :rtype: str
        """
        return self._validator_address

    @validator_address.setter
    def validator_address(self, validator_address):
        """Sets the validator_address of this BlockResult.


        :param validator_address: The validator_address of this BlockResult.  # noqa: E501
        :type: str
        """

        self._validator_address = validator_address

    @property
    def reward(self):
        """Gets the reward of this BlockResult.  # noqa: E501


        :return: The reward of this BlockResult.  # noqa: E501
        :rtype: str
        """
        return self._reward

    @reward.setter
    def reward(self, reward):
        """Sets the reward of this BlockResult.


        :param reward: The reward of this BlockResult.  # noqa: E501
        :type: str
        """

        self._reward = reward

    @property
    def events(self):
        """Gets the events of this BlockResult.  # noqa: E501


        :return: The events of this BlockResult.  # noqa: E501
        :rtype: list[EventResult]
        """
        return self._events

    @events.setter
    def events(self, events):
        """Sets the events of this BlockResult.


        :param events: The events of this BlockResult.  # noqa: E501
        :type: list[EventResult]
        """

        self._events = events

    @property
    def oracles(self):
        """Gets the oracles of this BlockResult.  # noqa: E501


        :return: The oracles of this BlockResult.  # noqa: E501
        :rtype: list[OracleResult]
        """
        return self._oracles

    @oracles.setter
    def oracles(self, oracles):
        """Sets the oracles of this BlockResult.


        :param oracles: The oracles of this BlockResult.  # noqa: E501
        :type: list[OracleResult]
        """

        self._oracles = oracles

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BlockResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BlockResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import struct
import io
import inspect
from typing import Callable, Any, Type


# TODO: Implement the Serialization class
class Serialization:
    _custom_serializers = {}  # Dictionary to store custom serializers

    @staticmethod
    def register_type(cls: Type, reader: Callable, writer: Callable):
        Serialization._custom_serializers[cls] = (reader, writer)

    @staticmethod
    def serialize(obj: Any) -> bytes:
        if obj is None:
            return b''

        # Check for custom serialization
        if type(obj) in Serialization._custom_serializers:
            writer = Serialization._custom_serializers[type(obj)][1]
            stream = io.BytesIO()
            writer(stream, obj)
            return stream.getvalue()

        # Handle basic types
        if isinstance(obj, bool):
            return struct.pack('?', obj)
        elif isinstance(obj, int):
            return struct.pack('<i', obj)
        # ... other basic types ...

        # Handle complex objects
        # This would require a more complex implementation
        # ...

        raise ValueError(f"Unsupported type: {type(obj)}")

    @staticmethod
    def unserialize(data: bytes, cls: Type) -> Any:
        if not data:
            return None

        # Check for custom deserialization
        if cls in Serialization._custom_serializers:
            reader = Serialization._custom_serializers[cls][0]
            stream = io.BytesIO(data)
            return reader(stream)

        # Handle basic types
        if cls == bool:
            return struct.unpack('?', data)[0]
        elif cls == int:
            return struct.unpack('<i', data)[0]
        # ... other basic types ...

        # Handle complex objects
        # This would require a more complex implementation
        # ...

        raise ValueError(f"Unsupported type: {cls}")

    # ... other methods ...



# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ScriptResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'events': 'list[EventResult]',
        'result': 'str',
        'error': 'str',
        'results': 'list[str]',
        'oracles': 'list[OracleResult]'
    }

    attribute_map = {
        'events': 'events',
        'result': 'result',
        'error': 'error',
        'results': 'results',
        'oracles': 'oracles'
    }

    def __init__(self, events=None, result=None, error=None, results=None, oracles=None):  # noqa: E501
        """ScriptResult - a model defined in Swagger"""  # noqa: E501
        self._events = None
        self._result = None
        self._error = None
        self._results = None
        self._oracles = None
        self.discriminator = None
        if events is not None:
            self.events = events
        if result is not None:
            self.result = result
        if error is not None:
            self.error = error
        if results is not None:
            self.results = results
        if oracles is not None:
            self.oracles = oracles

    @property
    def events(self):
        """Gets the events of this ScriptResult.  # noqa: E501


        :return: The events of this ScriptResult.  # noqa: E501
        :rtype: list[EventResult]
        """
        return self._events

    @events.setter
    def events(self, events):
        """Sets the events of this ScriptResult.


        :param events: The events of this ScriptResult.  # noqa: E501
        :type: list[EventResult]
        """

        self._events = events

    @property
    def result(self):
        """Gets the result of this ScriptResult.  # noqa: E501


        :return: The result of this ScriptResult.  # noqa: E501
        :rtype: str
        """
        return self._result

    @result.setter
    def result(self, result):
        """Sets the result of this ScriptResult.


        :param result: The result of this ScriptResult.  # noqa: E501
        :type: str
        """

        self._result = result

    @property
    def error(self):
        """Gets the error of this ScriptResult.  # noqa: E501


        :return: The error of this ScriptResult.  # noqa: E501
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this ScriptResult.


        :param error: The error of this ScriptResult.  # noqa: E501
        :type: str
        """

        self._error = error

    @property
    def results(self):
        """Gets the results of this ScriptResult.  # noqa: E501


        :return: The results of this ScriptResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._results

    @results.setter
    def results(self, results):
        """Sets the results of this ScriptResult.


        :param results: The results of this ScriptResult.  # noqa: E501
        :type: list[str]
        """

        self._results = results

    @property
    def oracles(self):
        """Gets the oracles of this ScriptResult.  # noqa: E501


        :return: The oracles of this ScriptResult.  # noqa: E501
        :rtype: list[OracleResult]
        """
        return self._oracles

    @oracles.setter
    def oracles(self, oracles):
        """Sets the oracles of this ScriptResult.


        :param oracles: The oracles of this ScriptResult.  # noqa: E501
        :type: list[OracleResult]
        """

        self._oracles = oracles

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ScriptResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScriptResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from .VM import *
from .Utils import *
from .Types import *
from .Tx import *
from .Interfaces import *
from .RPC import *

__all__ = [
    "VM",
    "Utils",
    "Types",
    "Tx",
    "Interfaces",
    "RPC"
]


# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TokenDataResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'series': 'str',
        'mint': 'str',
        'chain_name': 'str',
        'owner_address': 'str',
        'creator_address': 'str',
        'ram': 'str',
        'rom': 'str',
        'status': 'str',
        'infusion': 'list[TokenPropertyResult]',
        'properties': 'list[TokenPropertyResult]'
    }

    attribute_map = {
        'id': 'id',
        'series': 'series',
        'mint': 'mint',
        'chain_name': 'chainName',
        'owner_address': 'ownerAddress',
        'creator_address': 'creatorAddress',
        'ram': 'ram',
        'rom': 'rom',
        'status': 'status',
        'infusion': 'infusion',
        'properties': 'properties'
    }

    def __init__(self, id=None, series=None, mint=None, chain_name=None, owner_address=None, creator_address=None, ram=None, rom=None, status=None, infusion=None, properties=None):  # noqa: E501
        """TokenDataResult - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._series = None
        self._mint = None
        self._chain_name = None
        self._owner_address = None
        self._creator_address = None
        self._ram = None
        self._rom = None
        self._status = None
        self._infusion = None
        self._properties = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if series is not None:
            self.series = series
        if mint is not None:
            self.mint = mint
        if chain_name is not None:
            self.chain_name = chain_name
        if owner_address is not None:
            self.owner_address = owner_address
        if creator_address is not None:
            self.creator_address = creator_address
        if ram is not None:
            self.ram = ram
        if rom is not None:
            self.rom = rom
        if status is not None:
            self.status = status
        if infusion is not None:
            self.infusion = infusion
        if properties is not None:
            self.properties = properties

    @property
    def id(self):
        """Gets the id of this TokenDataResult.  # noqa: E501


        :return: The id of this TokenDataResult.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TokenDataResult.


        :param id: The id of this TokenDataResult.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def series(self):
        """Gets the series of this TokenDataResult.  # noqa: E501


        :return: The series of this TokenDataResult.  # noqa: E501
        :rtype: str
        """
        return self._series

    @series.setter
    def series(self, series):
        """Sets the series of this TokenDataResult.


        :param series: The series of this TokenDataResult.  # noqa: E501
        :type: str
        """

        self._series = series

    @property
    def mint(self):
        """Gets the mint of this TokenDataResult.  # noqa: E501


        :return: The mint of this TokenDataResult.  # noqa: E501
        :rtype: str
        """
        return self._mint

    @mint.setter
    def mint(self, mint):
        """Sets the mint of this TokenDataResult.


        :param mint: The mint of this TokenDataResult.  # noqa: E501
        :type: str
        """

        self._mint = mint

    @property
    def chain_name(self):
        """Gets the chain_name of this TokenDataResult.  # noqa: E501


        :return: The chain_name of this TokenDataResult.  # noqa: E501
        :rtype: str
        """
        return self._chain_name

    @chain_name.setter
    def chain_name(self, chain_name):
        """Sets the chain_name of this TokenDataResult.


        :param chain_name: The chain_name of this TokenDataResult.  # noqa: E501
        :type: str
        """

        self._chain_name = chain_name

    @property
    def owner_address(self):
        """Gets the owner_address of this TokenDataResult.  # noqa: E501


        :return: The owner_address of this TokenDataResult.  # noqa: E501
        :rtype: str
        """
        return self._owner_address

    @owner_address.setter
    def owner_address(self, owner_address):
        """Sets the owner_address of this TokenDataResult.


        :param owner_address: The owner_address of this TokenDataResult.  # noqa: E501
        :type: str
        """

        self._owner_address = owner_address

    @property
    def creator_address(self):
        """Gets the creator_address of this TokenDataResult.  # noqa: E501


        :return: The creator_address of this TokenDataResult.  # noqa: E501
        :rtype: str
        """
        return self._creator_address

    @creator_address.setter
    def creator_address(self, creator_address):
        """Sets the creator_address of this TokenDataResult.


        :param creator_address: The creator_address of this TokenDataResult.  # noqa: E501
        :type: str
        """

        self._creator_address = creator_address

    @property
    def ram(self):
        """Gets the ram of this TokenDataResult.  # noqa: E501


        :return: The ram of this TokenDataResult.  # noqa: E501
        :rtype: str
        """
        return self._ram

    @ram.setter
    def ram(self, ram):
        """Sets the ram of this TokenDataResult.


        :param ram: The ram of this TokenDataResult.  # noqa: E501
        :type: str
        """

        self._ram = ram

    @property
    def rom(self):
        """Gets the rom of this TokenDataResult.  # noqa: E501


        :return: The rom of this TokenDataResult.  # noqa: E501
        :rtype: str
        """
        return self._rom

    @rom.setter
    def rom(self, rom):
        """Sets the rom of this TokenDataResult.


        :param rom: The rom of this TokenDataResult.  # noqa: E501
        :type: str
        """

        self._rom = rom

    @property
    def status(self):
        """Gets the status of this TokenDataResult.  # noqa: E501


        :return: The status of this TokenDataResult.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this TokenDataResult.


        :param status: The status of this TokenDataResult.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def infusion(self):
        """Gets the infusion of this TokenDataResult.  # noqa: E501


        :return: The infusion of this TokenDataResult.  # noqa: E501
        :rtype: list[TokenPropertyResult]
        """
        return self._infusion

    @infusion.setter
    def infusion(self, infusion):
        """Sets the infusion of this TokenDataResult.


        :param infusion: The infusion of this TokenDataResult.  # noqa: E501
        :type: list[TokenPropertyResult]
        """

        self._infusion = infusion

    @property
    def properties(self):
        """Gets the properties of this TokenDataResult.  # noqa: E501


        :return: The properties of this TokenDataResult.  # noqa: E501
        :rtype: list[TokenPropertyResult]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this TokenDataResult.


        :param properties: The properties of this TokenDataResult.  # noqa: E501
        :type: list[TokenPropertyResult]
        """

        self._properties = properties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TokenDataResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TokenDataResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class NetInfoPeerConnectionStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'duration': 'str',
        'send_monitor': 'NetInfoPeerConnectionStatusMonitor',
        'recv_monitor': 'NetInfoPeerConnectionStatusMonitor',
        'channels': 'list[NetInfoPeerConnectionStatusChannel]'
    }

    attribute_map = {
        'duration': 'duration',
        'send_monitor': 'sendMonitor',
        'recv_monitor': 'recvMonitor',
        'channels': 'channels'
    }

    def __init__(self, duration=None, send_monitor=None, recv_monitor=None, channels=None):  # noqa: E501
        """NetInfoPeerConnectionStatus - a model defined in Swagger"""  # noqa: E501
        self._duration = None
        self._send_monitor = None
        self._recv_monitor = None
        self._channels = None
        self.discriminator = None
        if duration is not None:
            self.duration = duration
        if send_monitor is not None:
            self.send_monitor = send_monitor
        if recv_monitor is not None:
            self.recv_monitor = recv_monitor
        if channels is not None:
            self.channels = channels

    @property
    def duration(self):
        """Gets the duration of this NetInfoPeerConnectionStatus.  # noqa: E501


        :return: The duration of this NetInfoPeerConnectionStatus.  # noqa: E501
        :rtype: str
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this NetInfoPeerConnectionStatus.


        :param duration: The duration of this NetInfoPeerConnectionStatus.  # noqa: E501
        :type: str
        """

        self._duration = duration

    @property
    def send_monitor(self):
        """Gets the send_monitor of this NetInfoPeerConnectionStatus.  # noqa: E501


        :return: The send_monitor of this NetInfoPeerConnectionStatus.  # noqa: E501
        :rtype: NetInfoPeerConnectionStatusMonitor
        """
        return self._send_monitor

    @send_monitor.setter
    def send_monitor(self, send_monitor):
        """Sets the send_monitor of this NetInfoPeerConnectionStatus.


        :param send_monitor: The send_monitor of this NetInfoPeerConnectionStatus.  # noqa: E501
        :type: NetInfoPeerConnectionStatusMonitor
        """

        self._send_monitor = send_monitor

    @property
    def recv_monitor(self):
        """Gets the recv_monitor of this NetInfoPeerConnectionStatus.  # noqa: E501


        :return: The recv_monitor of this NetInfoPeerConnectionStatus.  # noqa: E501
        :rtype: NetInfoPeerConnectionStatusMonitor
        """
        return self._recv_monitor

    @recv_monitor.setter
    def recv_monitor(self, recv_monitor):
        """Sets the recv_monitor of this NetInfoPeerConnectionStatus.


        :param recv_monitor: The recv_monitor of this NetInfoPeerConnectionStatus.  # noqa: E501
        :type: NetInfoPeerConnectionStatusMonitor
        """

        self._recv_monitor = recv_monitor

    @property
    def channels(self):
        """Gets the channels of this NetInfoPeerConnectionStatus.  # noqa: E501


        :return: The channels of this NetInfoPeerConnectionStatus.  # noqa: E501
        :rtype: list[NetInfoPeerConnectionStatusChannel]
        """
        return self._channels

    @channels.setter
    def channels(self, channels):
        """Sets the channels of this NetInfoPeerConnectionStatus.


        :param channels: The channels of this NetInfoPeerConnectionStatus.  # noqa: E501
        :type: list[NetInfoPeerConnectionStatusChannel]
        """

        self._channels = channels

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NetInfoPeerConnectionStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NetInfoPeerConnectionStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class NetInfoPeerConnectionStatusChannel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'send_queue_capacity': 'str',
        'send_queue_size': 'str',
        'priority': 'str',
        'recently_sent': 'str'
    }

    attribute_map = {
        'id': 'id',
        'send_queue_capacity': 'sendQueueCapacity',
        'send_queue_size': 'sendQueueSize',
        'priority': 'priority',
        'recently_sent': 'recentlySent'
    }

    def __init__(self, id=None, send_queue_capacity=None, send_queue_size=None, priority=None, recently_sent=None):  # noqa: E501
        """NetInfoPeerConnectionStatusChannel - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._send_queue_capacity = None
        self._send_queue_size = None
        self._priority = None
        self._recently_sent = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if send_queue_capacity is not None:
            self.send_queue_capacity = send_queue_capacity
        if send_queue_size is not None:
            self.send_queue_size = send_queue_size
        if priority is not None:
            self.priority = priority
        if recently_sent is not None:
            self.recently_sent = recently_sent

    @property
    def id(self):
        """Gets the id of this NetInfoPeerConnectionStatusChannel.  # noqa: E501


        :return: The id of this NetInfoPeerConnectionStatusChannel.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this NetInfoPeerConnectionStatusChannel.


        :param id: The id of this NetInfoPeerConnectionStatusChannel.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def send_queue_capacity(self):
        """Gets the send_queue_capacity of this NetInfoPeerConnectionStatusChannel.  # noqa: E501


        :return: The send_queue_capacity of this NetInfoPeerConnectionStatusChannel.  # noqa: E501
        :rtype: str
        """
        return self._send_queue_capacity

    @send_queue_capacity.setter
    def send_queue_capacity(self, send_queue_capacity):
        """Sets the send_queue_capacity of this NetInfoPeerConnectionStatusChannel.


        :param send_queue_capacity: The send_queue_capacity of this NetInfoPeerConnectionStatusChannel.  # noqa: E501
        :type: str
        """

        self._send_queue_capacity = send_queue_capacity

    @property
    def send_queue_size(self):
        """Gets the send_queue_size of this NetInfoPeerConnectionStatusChannel.  # noqa: E501


        :return: The send_queue_size of this NetInfoPeerConnectionStatusChannel.  # noqa: E501
        :rtype: str
        """
        return self._send_queue_size

    @send_queue_size.setter
    def send_queue_size(self, send_queue_size):
        """Sets the send_queue_size of this NetInfoPeerConnectionStatusChannel.


        :param send_queue_size: The send_queue_size of this NetInfoPeerConnectionStatusChannel.  # noqa: E501
        :type: str
        """

        self._send_queue_size = send_queue_size

    @property
    def priority(self):
        """Gets the priority of this NetInfoPeerConnectionStatusChannel.  # noqa: E501


        :return: The priority of this NetInfoPeerConnectionStatusChannel.  # noqa: E501
        :rtype: str
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this NetInfoPeerConnectionStatusChannel.


        :param priority: The priority of this NetInfoPeerConnectionStatusChannel.  # noqa: E501
        :type: str
        """

        self._priority = priority

    @property
    def recently_sent(self):
        """Gets the recently_sent of this NetInfoPeerConnectionStatusChannel.  # noqa: E501


        :return: The recently_sent of this NetInfoPeerConnectionStatusChannel.  # noqa: E501
        :rtype: str
        """
        return self._recently_sent

    @recently_sent.setter
    def recently_sent(self, recently_sent):
        """Sets the recently_sent of this NetInfoPeerConnectionStatusChannel.


        :param recently_sent: The recently_sent of this NetInfoPeerConnectionStatusChannel.  # noqa: E501
        :type: str
        """

        self._recently_sent = recently_sent

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NetInfoPeerConnectionStatusChannel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NetInfoPeerConnectionStatusChannel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "phantasma-py"
VERSION = "1.0.6"
# To install the library, run the following
#
# python setup.py install
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil", "requests", "base58", "cryptography", "numpy", "ecpy"]

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name=NAME,
    version=VERSION,
    description="Phantasma SDK for Python",
    author_email="info@phantasma.io",
    url="https://phantasma.io/",
    keywords=["Swagger", "Phantasma API"],
    install_requires=REQUIRES,
    #packages=find_packages(),
    packages=find_packages(where="src"),
    package_dir={"": "src"},
    include_package_data=True,
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)



# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TokenSeriesResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'series_id': 'int',
        'current_supply': 'str',
        'max_supply': 'str',
        'burned_supply': 'str',
        'mode': 'str',
        'script': 'str',
        'methods': 'list[ABIMethodResult]'
    }

    attribute_map = {
        'series_id': 'seriesID',
        'current_supply': 'currentSupply',
        'max_supply': 'maxSupply',
        'burned_supply': 'burnedSupply',
        'mode': 'mode',
        'script': 'script',
        'methods': 'methods'
    }

    def __init__(self, series_id=None, current_supply=None, max_supply=None, burned_supply=None, mode=None, script=None, methods=None):  # noqa: E501
        """TokenSeriesResult - a model defined in Swagger"""  # noqa: E501
        self._series_id = None
        self._current_supply = None
        self._max_supply = None
        self._burned_supply = None
        self._mode = None
        self._script = None
        self._methods = None
        self.discriminator = None
        if series_id is not None:
            self.series_id = series_id
        if current_supply is not None:
            self.current_supply = current_supply
        if max_supply is not None:
            self.max_supply = max_supply
        if burned_supply is not None:
            self.burned_supply = burned_supply
        if mode is not None:
            self.mode = mode
        if script is not None:
            self.script = script
        if methods is not None:
            self.methods = methods

    @property
    def series_id(self):
        """Gets the series_id of this TokenSeriesResult.  # noqa: E501


        :return: The series_id of this TokenSeriesResult.  # noqa: E501
        :rtype: int
        """
        return self._series_id

    @series_id.setter
    def series_id(self, series_id):
        """Sets the series_id of this TokenSeriesResult.


        :param series_id: The series_id of this TokenSeriesResult.  # noqa: E501
        :type: int
        """

        self._series_id = series_id

    @property
    def current_supply(self):
        """Gets the current_supply of this TokenSeriesResult.  # noqa: E501


        :return: The current_supply of this TokenSeriesResult.  # noqa: E501
        :rtype: str
        """
        return self._current_supply

    @current_supply.setter
    def current_supply(self, current_supply):
        """Sets the current_supply of this TokenSeriesResult.


        :param current_supply: The current_supply of this TokenSeriesResult.  # noqa: E501
        :type: str
        """

        self._current_supply = current_supply

    @property
    def max_supply(self):
        """Gets the max_supply of this TokenSeriesResult.  # noqa: E501


        :return: The max_supply of this TokenSeriesResult.  # noqa: E501
        :rtype: str
        """
        return self._max_supply

    @max_supply.setter
    def max_supply(self, max_supply):
        """Sets the max_supply of this TokenSeriesResult.


        :param max_supply: The max_supply of this TokenSeriesResult.  # noqa: E501
        :type: str
        """

        self._max_supply = max_supply

    @property
    def burned_supply(self):
        """Gets the burned_supply of this TokenSeriesResult.  # noqa: E501


        :return: The burned_supply of this TokenSeriesResult.  # noqa: E501
        :rtype: str
        """
        return self._burned_supply

    @burned_supply.setter
    def burned_supply(self, burned_supply):
        """Sets the burned_supply of this TokenSeriesResult.


        :param burned_supply: The burned_supply of this TokenSeriesResult.  # noqa: E501
        :type: str
        """

        self._burned_supply = burned_supply

    @property
    def mode(self):
        """Gets the mode of this TokenSeriesResult.  # noqa: E501


        :return: The mode of this TokenSeriesResult.  # noqa: E501
        :rtype: str
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """Sets the mode of this TokenSeriesResult.


        :param mode: The mode of this TokenSeriesResult.  # noqa: E501
        :type: str
        """

        self._mode = mode

    @property
    def script(self):
        """Gets the script of this TokenSeriesResult.  # noqa: E501


        :return: The script of this TokenSeriesResult.  # noqa: E501
        :rtype: str
        """
        return self._script

    @script.setter
    def script(self, script):
        """Sets the script of this TokenSeriesResult.


        :param script: The script of this TokenSeriesResult.  # noqa: E501
        :type: str
        """

        self._script = script

    @property
    def methods(self):
        """Gets the methods of this TokenSeriesResult.  # noqa: E501


        :return: The methods of this TokenSeriesResult.  # noqa: E501
        :rtype: list[ABIMethodResult]
        """
        return self._methods

    @methods.setter
    def methods(self, methods):
        """Sets the methods of this TokenSeriesResult.


        :param methods: The methods of this TokenSeriesResult.  # noqa: E501
        :type: list[ABIMethodResult]
        """

        self._methods = methods

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TokenSeriesResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TokenSeriesResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




class StakeReward:
    def __init__(self, staker, date):
        self.staker = staker
        self.date = date

class DomainSettings:
    LatestKnownProtocol = 18
    Phantasma20Protocol = 7
    Phantasma30Protocol = 8
    MaxTxPerBlock = 1024
    MaxOracleEntriesPerBlock = 5120
    MaxEventsPerBlock = 2048
    MaxEventsPerTx = 8096
    MaxTriggerLoop = 5
    MAX_TOKEN_DECIMALS = 18
    DefaultMinimumGasFee = 100000
    InitialValidatorCount = 4
    FuelTokenSymbol = 'KCAL'
    FuelTokenName = 'Phantasma Energy'
    FuelTokenDecimals = 10
    NexusMainnet = 'mainnet'
    NexusTestnet = 'testnet'
    StakingTokenSymbol = 'SOUL'
    StakingTokenName = 'Phantasma Stake'
    StakingTokenDecimals = 8
    FiatTokenSymbol = 'USD'
    FiatTokenName = 'Dollars'
    FiatTokenDecimals = 8
    RewardTokenSymbol = 'CROWN'
    RewardTokenName = 'Phantasma Crown'
    LiquidityTokenSymbol = 'LP'
    LiquidityTokenName = 'Phantasma Liquidity'
    LiquidityTokenDecimals = 8
    FuelPerContractDeployTag = 'nexus.contract.cost'
    FuelPerTokenDeployTag = 'nexus.token.cost'
    FuelPerOrganizationDeployTag = 'nexus.organization.cost'
    SystemTokens = [
        FuelTokenSymbol,
        StakingTokenSymbol,
        FiatTokenSymbol,
        RewardTokenSymbol,
        LiquidityTokenSymbol,
    ]
    RootChainName = 'main'
    ValidatorsOrganizationName = 'validators'
    MastersOrganizationName = 'masters'
    StakersOrganizationName = 'stakers'
    PhantomForceOrganizationName = 'phantom_force'
    PlatformName = 'phantasma'
    ArchiveMinSize = 64
    ArchiveMaxSize = 104857600
    InfusionName = 'infusion'
    NameMaxLength = 255
    UrlMaxLength = 2048
    ArgsMax = 64
    AddressMaxSize = 34
    ScriptMaxSize = 32767



# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CrowdsaleResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'hash': 'str',
        'name': 'str',
        'creator': 'str',
        'flags': 'str',
        'start_date': 'int',
        'end_date': 'int',
        'sell_symbol': 'str',
        'receive_symbol': 'str',
        'price': 'int',
        'global_soft_cap': 'str',
        'global_hard_cap': 'str',
        'user_soft_cap': 'str',
        'user_hard_cap': 'str'
    }

    attribute_map = {
        'hash': 'hash',
        'name': 'name',
        'creator': 'creator',
        'flags': 'flags',
        'start_date': 'startDate',
        'end_date': 'endDate',
        'sell_symbol': 'sellSymbol',
        'receive_symbol': 'receiveSymbol',
        'price': 'price',
        'global_soft_cap': 'globalSoftCap',
        'global_hard_cap': 'globalHardCap',
        'user_soft_cap': 'userSoftCap',
        'user_hard_cap': 'userHardCap'
    }

    def __init__(self, hash=None, name=None, creator=None, flags=None, start_date=None, end_date=None, sell_symbol=None, receive_symbol=None, price=None, global_soft_cap=None, global_hard_cap=None, user_soft_cap=None, user_hard_cap=None):  # noqa: E501
        """CrowdsaleResult - a model defined in Swagger"""  # noqa: E501
        self._hash = None
        self._name = None
        self._creator = None
        self._flags = None
        self._start_date = None
        self._end_date = None
        self._sell_symbol = None
        self._receive_symbol = None
        self._price = None
        self._global_soft_cap = None
        self._global_hard_cap = None
        self._user_soft_cap = None
        self._user_hard_cap = None
        self.discriminator = None
        if hash is not None:
            self.hash = hash
        if name is not None:
            self.name = name
        if creator is not None:
            self.creator = creator
        if flags is not None:
            self.flags = flags
        if start_date is not None:
            self.start_date = start_date
        if end_date is not None:
            self.end_date = end_date
        if sell_symbol is not None:
            self.sell_symbol = sell_symbol
        if receive_symbol is not None:
            self.receive_symbol = receive_symbol
        if price is not None:
            self.price = price
        if global_soft_cap is not None:
            self.global_soft_cap = global_soft_cap
        if global_hard_cap is not None:
            self.global_hard_cap = global_hard_cap
        if user_soft_cap is not None:
            self.user_soft_cap = user_soft_cap
        if user_hard_cap is not None:
            self.user_hard_cap = user_hard_cap

    @property
    def hash(self):
        """Gets the hash of this CrowdsaleResult.  # noqa: E501


        :return: The hash of this CrowdsaleResult.  # noqa: E501
        :rtype: str
        """
        return self._hash

    @hash.setter
    def hash(self, hash):
        """Sets the hash of this CrowdsaleResult.


        :param hash: The hash of this CrowdsaleResult.  # noqa: E501
        :type: str
        """

        self._hash = hash

    @property
    def name(self):
        """Gets the name of this CrowdsaleResult.  # noqa: E501


        :return: The name of this CrowdsaleResult.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CrowdsaleResult.


        :param name: The name of this CrowdsaleResult.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def creator(self):
        """Gets the creator of this CrowdsaleResult.  # noqa: E501


        :return: The creator of this CrowdsaleResult.  # noqa: E501
        :rtype: str
        """
        return self._creator

    @creator.setter
    def creator(self, creator):
        """Sets the creator of this CrowdsaleResult.


        :param creator: The creator of this CrowdsaleResult.  # noqa: E501
        :type: str
        """

        self._creator = creator

    @property
    def flags(self):
        """Gets the flags of this CrowdsaleResult.  # noqa: E501


        :return: The flags of this CrowdsaleResult.  # noqa: E501
        :rtype: str
        """
        return self._flags

    @flags.setter
    def flags(self, flags):
        """Sets the flags of this CrowdsaleResult.


        :param flags: The flags of this CrowdsaleResult.  # noqa: E501
        :type: str
        """

        self._flags = flags

    @property
    def start_date(self):
        """Gets the start_date of this CrowdsaleResult.  # noqa: E501


        :return: The start_date of this CrowdsaleResult.  # noqa: E501
        :rtype: int
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this CrowdsaleResult.


        :param start_date: The start_date of this CrowdsaleResult.  # noqa: E501
        :type: int
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this CrowdsaleResult.  # noqa: E501


        :return: The end_date of this CrowdsaleResult.  # noqa: E501
        :rtype: int
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this CrowdsaleResult.


        :param end_date: The end_date of this CrowdsaleResult.  # noqa: E501
        :type: int
        """

        self._end_date = end_date

    @property
    def sell_symbol(self):
        """Gets the sell_symbol of this CrowdsaleResult.  # noqa: E501


        :return: The sell_symbol of this CrowdsaleResult.  # noqa: E501
        :rtype: str
        """
        return self._sell_symbol

    @sell_symbol.setter
    def sell_symbol(self, sell_symbol):
        """Sets the sell_symbol of this CrowdsaleResult.


        :param sell_symbol: The sell_symbol of this CrowdsaleResult.  # noqa: E501
        :type: str
        """

        self._sell_symbol = sell_symbol

    @property
    def receive_symbol(self):
        """Gets the receive_symbol of this CrowdsaleResult.  # noqa: E501


        :return: The receive_symbol of this CrowdsaleResult.  # noqa: E501
        :rtype: str
        """
        return self._receive_symbol

    @receive_symbol.setter
    def receive_symbol(self, receive_symbol):
        """Sets the receive_symbol of this CrowdsaleResult.


        :param receive_symbol: The receive_symbol of this CrowdsaleResult.  # noqa: E501
        :type: str
        """

        self._receive_symbol = receive_symbol

    @property
    def price(self):
        """Gets the price of this CrowdsaleResult.  # noqa: E501


        :return: The price of this CrowdsaleResult.  # noqa: E501
        :rtype: int
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this CrowdsaleResult.


        :param price: The price of this CrowdsaleResult.  # noqa: E501
        :type: int
        """

        self._price = price

    @property
    def global_soft_cap(self):
        """Gets the global_soft_cap of this CrowdsaleResult.  # noqa: E501


        :return: The global_soft_cap of this CrowdsaleResult.  # noqa: E501
        :rtype: str
        """
        return self._global_soft_cap

    @global_soft_cap.setter
    def global_soft_cap(self, global_soft_cap):
        """Sets the global_soft_cap of this CrowdsaleResult.


        :param global_soft_cap: The global_soft_cap of this CrowdsaleResult.  # noqa: E501
        :type: str
        """

        self._global_soft_cap = global_soft_cap

    @property
    def global_hard_cap(self):
        """Gets the global_hard_cap of this CrowdsaleResult.  # noqa: E501


        :return: The global_hard_cap of this CrowdsaleResult.  # noqa: E501
        :rtype: str
        """
        return self._global_hard_cap

    @global_hard_cap.setter
    def global_hard_cap(self, global_hard_cap):
        """Sets the global_hard_cap of this CrowdsaleResult.


        :param global_hard_cap: The global_hard_cap of this CrowdsaleResult.  # noqa: E501
        :type: str
        """

        self._global_hard_cap = global_hard_cap

    @property
    def user_soft_cap(self):
        """Gets the user_soft_cap of this CrowdsaleResult.  # noqa: E501


        :return: The user_soft_cap of this CrowdsaleResult.  # noqa: E501
        :rtype: str
        """
        return self._user_soft_cap

    @user_soft_cap.setter
    def user_soft_cap(self, user_soft_cap):
        """Sets the user_soft_cap of this CrowdsaleResult.


        :param user_soft_cap: The user_soft_cap of this CrowdsaleResult.  # noqa: E501
        :type: str
        """

        self._user_soft_cap = user_soft_cap

    @property
    def user_hard_cap(self):
        """Gets the user_hard_cap of this CrowdsaleResult.  # noqa: E501


        :return: The user_hard_cap of this CrowdsaleResult.  # noqa: E501
        :rtype: str
        """
        return self._user_hard_cap

    @user_hard_cap.setter
    def user_hard_cap(self, user_hard_cap):
        """Sets the user_hard_cap of this CrowdsaleResult.


        :param user_hard_cap: The user_hard_cap of this CrowdsaleResult.  # noqa: E501
        :type: str
        """

        self._user_hard_cap = user_hard_cap

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CrowdsaleResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CrowdsaleResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#import big_int  # Assuming big_int is a Python equivalent of big-integer library

class Decoder:
    def __init__(self, str):
        self.str = str

    def is_end(self):
        return len(self.str) == 0

    def read_char_pair(self):
        res = self.str[:2]
        self.str = self.str[2:]
        return res

    def read_byte(self):
        try:
            return int(self.read_char_pair(), 16)
        except ValueError as e:
            # Handle the error or re-raise with a more descriptive message
            raise ValueError(f"read_char_pair() returned an invalid hexadecimal value: {e}")

    def read(self, num_bytes):
        res = self.str[:num_bytes * 2]
        self.str = self.str[num_bytes * 2:]
        return res

    def read_string(self):
        length = self.read_var_int()
        return self.read_string_bytes(length)

    def read_string_bytes(self, num_bytes):
        res = ''
        for _ in range(num_bytes):
            res += chr(self.read_byte())
        return res

    def read_byte_array(self):
        length = self.read_var_int()
        if length == 0:
            return []
        return self.read(length)

    def read_signature(self):
        # Implement as per your signature structure
        pass

    def read_timestamp(self):
        bytes_str = self.read(4)
        result = 0
        for c in reversed([bytes_str[i:i+2] for i in range(0, len(bytes_str), 2)]):
            result = result * 256 + int(c, 16)
        return result

    def read_var_int(self):
        length = self.read_byte()
        res = 0
        if length == 0xfd:
            for c in reversed(self.read(2)):
                res = res * 256 + int(c, 16)
        elif length == 0xfe:
            for c in reversed(self.read(4)):
                res = res * 256 + int(c, 16)
        elif length == 0xff:
            for c in reversed(self.read(8)):
                res = res * 256 + int(c, 16)
        else:
            res = length
        return res

    def read_big_int(self):
        length = self.read_var_int()
        res = 0
        string_bytes = self.read(length)
        for c in reversed([string_bytes[i:i+2] for i in range(0, len(string_bytes), 2)]):
            res = res * 256 + int(c, 16)
        return res

    def read_big_int_accurate(self):
        length = self.read_var_int()
        res = big_int.BigInt()
        string_bytes = self.read(length)
        for c in reversed([string_bytes[i:i+2] for i in range(0, len(string_bytes), 2)]):
            res = res.times(256).plus(int(c, 16))
        return res.toString()

    def read_vm_object(self):
        # Implement as per your VM object structure
        pass



# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class NexusResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'protocol': 'int',
        'platforms': 'list[PlatformResult]',
        'tokens': 'list[TokenResult]',
        'chains': 'list[ChainResult]',
        'governance': 'list[GovernanceResult]',
        'organizations': 'list[str]'
    }

    attribute_map = {
        'name': 'name',
        'protocol': 'protocol',
        'platforms': 'platforms',
        'tokens': 'tokens',
        'chains': 'chains',
        'governance': 'governance',
        'organizations': 'organizations'
    }

    def __init__(self, name=None, protocol=None, platforms=None, tokens=None, chains=None, governance=None, organizations=None):  # noqa: E501
        """NexusResult - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._protocol = None
        self._platforms = None
        self._tokens = None
        self._chains = None
        self._governance = None
        self._organizations = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if protocol is not None:
            self.protocol = protocol
        if platforms is not None:
            self.platforms = platforms
        if tokens is not None:
            self.tokens = tokens
        if chains is not None:
            self.chains = chains
        if governance is not None:
            self.governance = governance
        if organizations is not None:
            self.organizations = organizations

    @property
    def name(self):
        """Gets the name of this NexusResult.  # noqa: E501


        :return: The name of this NexusResult.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this NexusResult.


        :param name: The name of this NexusResult.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def protocol(self):
        """Gets the protocol of this NexusResult.  # noqa: E501


        :return: The protocol of this NexusResult.  # noqa: E501
        :rtype: int
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this NexusResult.


        :param protocol: The protocol of this NexusResult.  # noqa: E501
        :type: int
        """

        self._protocol = protocol

    @property
    def platforms(self):
        """Gets the platforms of this NexusResult.  # noqa: E501


        :return: The platforms of this NexusResult.  # noqa: E501
        :rtype: list[PlatformResult]
        """
        return self._platforms

    @platforms.setter
    def platforms(self, platforms):
        """Sets the platforms of this NexusResult.


        :param platforms: The platforms of this NexusResult.  # noqa: E501
        :type: list[PlatformResult]
        """

        self._platforms = platforms

    @property
    def tokens(self):
        """Gets the tokens of this NexusResult.  # noqa: E501


        :return: The tokens of this NexusResult.  # noqa: E501
        :rtype: list[TokenResult]
        """
        return self._tokens

    @tokens.setter
    def tokens(self, tokens):
        """Sets the tokens of this NexusResult.


        :param tokens: The tokens of this NexusResult.  # noqa: E501
        :type: list[TokenResult]
        """

        self._tokens = tokens

    @property
    def chains(self):
        """Gets the chains of this NexusResult.  # noqa: E501


        :return: The chains of this NexusResult.  # noqa: E501
        :rtype: list[ChainResult]
        """
        return self._chains

    @chains.setter
    def chains(self, chains):
        """Sets the chains of this NexusResult.


        :param chains: The chains of this NexusResult.  # noqa: E501
        :type: list[ChainResult]
        """

        self._chains = chains

    @property
    def governance(self):
        """Gets the governance of this NexusResult.  # noqa: E501


        :return: The governance of this NexusResult.  # noqa: E501
        :rtype: list[GovernanceResult]
        """
        return self._governance

    @governance.setter
    def governance(self, governance):
        """Sets the governance of this NexusResult.


        :param governance: The governance of this NexusResult.  # noqa: E501
        :type: list[GovernanceResult]
        """

        self._governance = governance

    @property
    def organizations(self):
        """Gets the organizations of this NexusResult.  # noqa: E501


        :return: The organizations of this NexusResult.  # noqa: E501
        :rtype: list[str]
        """
        return self._organizations

    @organizations.setter
    def organizations(self, organizations):
        """Sets the organizations of this NexusResult.


        :param organizations: The organizations of this NexusResult.  # noqa: E501
        :type: list[str]
        """

        self._organizations = organizations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NexusResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NexusResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from enum import Enum

class EventKind(Enum):
    Unknown = 0
    ChainCreate = 1
    TokenCreate = 2
    TokenSend = 3
    TokenReceive = 4
    TokenMint = 5
    TokenBurn = 6
    TokenStake = 7
    TokenClaim = 8
    AddressRegister = 9
    AddressLink = 10
    AddressUnlink = 11
    OrganizationCreate = 12
    OrganizationAdd = 13
    OrganizationRemove = 14
    GasEscrow = 15
    GasPayment = 16
    AddressUnregister = 17
    OrderCreated = 18
    OrderCancelled = 19
    OrderFilled = 20
    OrderClosed = 21
    FeedCreate = 22
    FeedUpdate = 23
    FileCreate = 24
    FileDelete = 25
    ValidatorPropose = 26
    ValidatorElect = 27
    ValidatorRemove = 28
    ValidatorSwitch = 29
    PackedNFT = 30
    ValueCreate = 31
    ValueUpdate = 32
    PollCreated = 33
    PollClosed = 34
    PollVote = 35
    ChannelCreate = 36
    ChannelRefill = 37
    ChannelSettle = 38
    LeaderboardCreate = 39
    LeaderboardInsert = 40
    LeaderboardReset = 41
    PlatformCreate = 42
    ChainSwap = 43
    ContractRegister = 44
    ContractDeploy = 45
    AddressMigration = 46
    ContractUpgrade = 47
    Log = 48
    Inflation = 49
    OrderBid = 59
    MasterClaim = 61
    Custom = 64


# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class NodeInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'protocol_version': 'NodeInfoProtocolVersion',
        'id': 'str',
        'listen_addr': 'str',
        'network': 'str',
        'version': 'str',
        'channels': 'str',
        'moniker': 'str',
        'other': 'NodeInfoOther'
    }

    attribute_map = {
        'protocol_version': 'protocolVersion',
        'id': 'id',
        'listen_addr': 'listenAddr',
        'network': 'network',
        'version': 'version',
        'channels': 'channels',
        'moniker': 'moniker',
        'other': 'other'
    }

    def __init__(self, protocol_version=None, id=None, listen_addr=None, network=None, version=None, channels=None, moniker=None, other=None):  # noqa: E501
        """NodeInfo - a model defined in Swagger"""  # noqa: E501
        self._protocol_version = None
        self._id = None
        self._listen_addr = None
        self._network = None
        self._version = None
        self._channels = None
        self._moniker = None
        self._other = None
        self.discriminator = None
        if protocol_version is not None:
            self.protocol_version = protocol_version
        if id is not None:
            self.id = id
        if listen_addr is not None:
            self.listen_addr = listen_addr
        if network is not None:
            self.network = network
        if version is not None:
            self.version = version
        if channels is not None:
            self.channels = channels
        if moniker is not None:
            self.moniker = moniker
        if other is not None:
            self.other = other

    @property
    def protocol_version(self):
        """Gets the protocol_version of this NodeInfo.  # noqa: E501


        :return: The protocol_version of this NodeInfo.  # noqa: E501
        :rtype: NodeInfoProtocolVersion
        """
        return self._protocol_version

    @protocol_version.setter
    def protocol_version(self, protocol_version):
        """Sets the protocol_version of this NodeInfo.


        :param protocol_version: The protocol_version of this NodeInfo.  # noqa: E501
        :type: NodeInfoProtocolVersion
        """

        self._protocol_version = protocol_version

    @property
    def id(self):
        """Gets the id of this NodeInfo.  # noqa: E501


        :return: The id of this NodeInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this NodeInfo.


        :param id: The id of this NodeInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def listen_addr(self):
        """Gets the listen_addr of this NodeInfo.  # noqa: E501


        :return: The listen_addr of this NodeInfo.  # noqa: E501
        :rtype: str
        """
        return self._listen_addr

    @listen_addr.setter
    def listen_addr(self, listen_addr):
        """Sets the listen_addr of this NodeInfo.


        :param listen_addr: The listen_addr of this NodeInfo.  # noqa: E501
        :type: str
        """

        self._listen_addr = listen_addr

    @property
    def network(self):
        """Gets the network of this NodeInfo.  # noqa: E501


        :return: The network of this NodeInfo.  # noqa: E501
        :rtype: str
        """
        return self._network

    @network.setter
    def network(self, network):
        """Sets the network of this NodeInfo.


        :param network: The network of this NodeInfo.  # noqa: E501
        :type: str
        """

        self._network = network

    @property
    def version(self):
        """Gets the version of this NodeInfo.  # noqa: E501


        :return: The version of this NodeInfo.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this NodeInfo.


        :param version: The version of this NodeInfo.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def channels(self):
        """Gets the channels of this NodeInfo.  # noqa: E501


        :return: The channels of this NodeInfo.  # noqa: E501
        :rtype: str
        """
        return self._channels

    @channels.setter
    def channels(self, channels):
        """Sets the channels of this NodeInfo.


        :param channels: The channels of this NodeInfo.  # noqa: E501
        :type: str
        """

        self._channels = channels

    @property
    def moniker(self):
        """Gets the moniker of this NodeInfo.  # noqa: E501


        :return: The moniker of this NodeInfo.  # noqa: E501
        :rtype: str
        """
        return self._moniker

    @moniker.setter
    def moniker(self, moniker):
        """Sets the moniker of this NodeInfo.


        :param moniker: The moniker of this NodeInfo.  # noqa: E501
        :type: str
        """

        self._moniker = moniker

    @property
    def other(self):
        """Gets the other of this NodeInfo.  # noqa: E501


        :return: The other of this NodeInfo.  # noqa: E501
        :rtype: NodeInfoOther
        """
        return self._other

    @other.setter
    def other(self, other):
        """Sets the other of this NodeInfo.


        :param other: The other of this NodeInfo.  # noqa: E501
        :type: NodeInfoOther
        """

        self._other = other

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NodeInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NodeInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from enum import Enum

class Contracts(Enum):
    GasContractName = "gas"
    BlockContractName = "block"
    StakeContractName = "stake"
    SwapContractName = "swap"
    AccountContractName = "account"
    ConsensusContractName = "consensus"
    GovernanceContractName = "governance"
    StorageContractName = "storage"
    ValidatorContractName = "validator"
    InteropContractName = "interop"
    ExchangeContractName = "exchange"
    PrivacyContractName = "privacy"
    RelayContractName = "relay"
    RankingContractName = "ranking"


from datetime import datetime

class Timestamp:
    def __init__(self, value: int):
        self.value = value

    def __str__(self):
        return datetime.utcfromtimestamp(self.value).strftime("%a, %d %b %Y %H:%M:%S GMT")

    def to_string_format(self, format_str: str):
        return datetime.utcfromtimestamp(self.value).strftime(format_str)

    @staticmethod
    def now():
        return int(datetime.now().timestamp())

    @staticmethod
    def null():
        return Timestamp(0)

    def compare_to(self, other):
        if self.value == other.value:
            return 0
        return -1 if self.value < other.value else 1

    def equals(self, obj):
        return isinstance(obj, Timestamp) and self.value == obj.value

    def get_hash_code(self):
        return self.value

    def get_size(self):
        return 4

    @staticmethod
    def equal(A, B):
        return A.value == B.value

    @staticmethod
    def not_equal(A, B):
        return A.value != B.value

    @staticmethod
    def less_than(A, B):
        return A.value < B.value

    @staticmethod
    def greater_than(A, B):
        return A.value > B.value

    @staticmethod
    def less_than_or_equal(A, B):
        return A.value <= B.value

    @staticmethod
    def greater_than_or_equal(A, B):
        return A.value >= B.value

    @staticmethod
    def subtract(A, B):
        return A.value - B.value

    @staticmethod
    def from_number(ticks):
        return Timestamp(ticks)

    @staticmethod
    def from_date(time):
        return Timestamp(int(time.timestamp()))

    @staticmethod
    def add_time_span(A, B):
        return A.value + B

    @staticmethod
    def subtract_time_span(A, B):
        return A.value - B

    # Serialize and Unserialize methods are placeholders
    @staticmethod
    def Serialize():
        pass

    @staticmethod
    def Unserialize():
        pass


# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TokenPriceResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'timestamp': 'int',
        'open': 'str',
        'high': 'str',
        'low': 'str',
        'close': 'str'
    }

    attribute_map = {
        'timestamp': 'timestamp',
        'open': 'open',
        'high': 'high',
        'low': 'low',
        'close': 'close'
    }

    def __init__(self, timestamp=None, open=None, high=None, low=None, close=None):  # noqa: E501
        """TokenPriceResult - a model defined in Swagger"""  # noqa: E501
        self._timestamp = None
        self._open = None
        self._high = None
        self._low = None
        self._close = None
        self.discriminator = None
        if timestamp is not None:
            self.timestamp = timestamp
        if open is not None:
            self.open = open
        if high is not None:
            self.high = high
        if low is not None:
            self.low = low
        if close is not None:
            self.close = close

    @property
    def timestamp(self):
        """Gets the timestamp of this TokenPriceResult.  # noqa: E501


        :return: The timestamp of this TokenPriceResult.  # noqa: E501
        :rtype: int
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this TokenPriceResult.


        :param timestamp: The timestamp of this TokenPriceResult.  # noqa: E501
        :type: int
        """

        self._timestamp = timestamp

    @property
    def open(self):
        """Gets the open of this TokenPriceResult.  # noqa: E501


        :return: The open of this TokenPriceResult.  # noqa: E501
        :rtype: str
        """
        return self._open

    @open.setter
    def open(self, open):
        """Sets the open of this TokenPriceResult.


        :param open: The open of this TokenPriceResult.  # noqa: E501
        :type: str
        """

        self._open = open

    @property
    def high(self):
        """Gets the high of this TokenPriceResult.  # noqa: E501


        :return: The high of this TokenPriceResult.  # noqa: E501
        :rtype: str
        """
        return self._high

    @high.setter
    def high(self, high):
        """Sets the high of this TokenPriceResult.


        :param high: The high of this TokenPriceResult.  # noqa: E501
        :type: str
        """

        self._high = high

    @property
    def low(self):
        """Gets the low of this TokenPriceResult.  # noqa: E501


        :return: The low of this TokenPriceResult.  # noqa: E501
        :rtype: str
        """
        return self._low

    @low.setter
    def low(self, low):
        """Sets the low of this TokenPriceResult.


        :param low: The low of this TokenPriceResult.  # noqa: E501
        :type: str
        """

        self._low = low

    @property
    def close(self):
        """Gets the close of this TokenPriceResult.  # noqa: E501


        :return: The close of this TokenPriceResult.  # noqa: E501
        :rtype: str
        """
        return self._close

    @close.setter
    def close(self, close):
        """Sets the close of this TokenPriceResult.


        :param close: The close of this TokenPriceResult.  # noqa: E501
        :type: str
        """

        self._close = close

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TokenPriceResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TokenPriceResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Phantasma API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.platform_api import PlatformApi  # noqa: E501
from swagger_client.rest import ApiException


class TestPlatformApi(unittest.TestCase):
    """PlatformApi unit test stubs"""

    def setUp(self):
        self.api = PlatformApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_api_v1_get_interop_get(self):
        """Test case for api_v1_get_interop_get

        """
        pass

    def test_api_v1_get_platform_get(self):
        """Test case for api_v1_get_platform_get

        """
        pass

    def test_api_v1_get_platforms_get(self):
        """Test case for api_v1_get_platforms_get

        """
        pass


if __name__ == '__main__':
    unittest.main()



from enum import Enum
from typing import NamedTuple, ByteString

from Types import Address

# Assuming Address and ContractInterface are defined elsewhere in your code
# from address import Address
# from contract_interface import ContractInterface

class TokenFlags(Enum):
    None_ = 0
    Transferable = 1 << 0
    Fungible = 1 << 1
    Finite = 1 << 2
    Divisible = 1 << 3
    Fuel = 1 << 4
    Stakable = 1 << 5
    Fiat = 1 << 6
    Swappable = 1 << 7
    Burnable = 1 << 8
    Mintable = 1 << 9

class TokenSeriesMode(Enum):
    Unique = 0
    Duplicated = 1

class IToken(NamedTuple):
    Name: str
    Symbol: str
    Owner: Address
    Flags: TokenFlags
    MaxSupply: int  # BigInteger in Python can be represented as int
    Decimals: int
    Script: ByteString
    ABI: ContractInterface

# Example Usage
# token = IToken(Name="MyToken", Symbol="MTK", Owner=address, Flags=TokenFlags.Fungible, MaxSupply=1000000, Decimals=2, Script=b'your_script', ABI=contract_interface)
